@@ -20,8 +20,6 @@
 #define MYSQL_DEFAULT_SQL_MODE	""
 #define MYSQL_DEFAULT_TIME_ZONE	"SYSTEM"
 
-#define PROXYSQL_MYSQL_PTHREAD_MUTEX
-
 static unsigned int near_pow_2 (unsigned int n) {
   unsigned int i = 1;
   while (i < n) i <<= 1;
@@ -248,11 +246,7 @@ class MySQL_Thread
 		bool stats_time_query_processor;
 	} variables;
 
-#ifdef PROXYSQL_MYSQL_PTHREAD_MUTEX
   pthread_mutex_t thread_mutex;
-#else
-  rwlock_t thread_mutex;
-#endif
   MySQL_Thread();
   ~MySQL_Thread();
   MySQL_Session * create_new_session_and_client_data_stream(int _fd);
@@ -320,11 +314,7 @@ class MySQL_Threads_Handler
 	int shutdown_;
 	size_t stacksize;
 	pthread_attr_t attr;
-#ifdef PROXYSQL_MYSQL_PTHREAD_MUTEX
 	pthread_rwlock_t rwlock;
-#else
-	rwlock_t rwlock;
-#endif
 	PtrArray *bind_fds;
 	MySQL_Listeners_Manager *MLM;
 	public:
@@ -407,6 +397,7 @@ class MySQL_Threads_Handler
 		int default_query_timeout;
 		int query_processor_iterations;
 		int query_processor_regex;
+		int auto_increment_delay_multiplex;
 		int long_query_time;
 		int hostgroup_manager_verbose;
 		char *init_connect;
