@@ -4,7 +4,7 @@
 #include <stdlib.h>
 #ifndef __STDC_LIMIT_MACROS
 #define __STDC_LIMIT_MACROS
-#endif
+#endif /* __STDC_LIMIT_MACROS */
 #include <stdint.h>
 #include <string.h>
 using namespace std;
